| old.html |  | new.html
--- | --- | --- | ---
f | 1 | <!-- | f | 1 | <!--
| 2 | HTML file automatically generated from DocOnce source |  | 2 | HTML file automatically generated from DocOnce source
| 3 | (https://github.com/doconce/doconce/) |  | 3 | (https://github.com/doconce/doconce/)
| 4 | doconce format html first.do.txt --examples_as_exercises --html_output=temp |  | 4 | doconce format html first.do.txt --examples_as_exercises --html_output=temp
| 5 | --> |  | 5 | -->
| 6 | <html> |  | 6 | <html>
| 7 | <head> |  | 7 | <head>
| 8 | <meta http-equiv="Content-Type" content="text/html; charset=utf-8" /> |  | 8 | <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
| 9 | <meta name="generator" content="DocOnce: https://github.com/doconce/doconce/" /> |  | 9 | <meta name="generator" content="DocOnce: https://github.com/doconce/doconce/" />
| 10 | <meta name="viewport" content="width=device-width, initial-scale=1.0" /> |  | 10 | <meta name="viewport" content="width=device-width, initial-scale=1.0" />
| 11 | <meta name="description" content="Minimal slide demo"> |  | 11 | <meta name="description" content="Minimal slide demo">
| 12 | <title>Minimal slide demo</title> |  | 12 | <title>Minimal slide demo</title>
| 13 | <style type="text/css"> |  | 13 | <style type="text/css">
| 14 | /* blueish style */ |  | 14 | /* blueish style */
| 15 | body { |  | 15 | body {
| 16 | margin-top: 1.0em; |  | 16 | margin-top: 1.0em;
| 17 | background-color: #ffffff; |  | 17 | background-color: #ffffff;
| 18 | font-family: Helvetica, Arial, FreeSans, san-serif; |  | 18 | font-family: Helvetica, Arial, FreeSans, san-serif;
| 19 | color: #000000; |  | 19 | color: #000000;
| 20 | } |  | 20 | }
| 21 | h1 { font-size: 1.8em; color: #1e36ce; } |  | 21 | h1 { font-size: 1.8em; color: #1e36ce; }
| 22 | h2 { font-size: 1.6em; color: #1e36ce; } |  | 22 | h2 { font-size: 1.6em; color: #1e36ce; }
| 23 | h3 { font-size: 1.4em; color: #1e36ce; } |  | 23 | h3 { font-size: 1.4em; color: #1e36ce; }
| 24 | h4 { font-size: 1.2em; color: #1e36ce; } |  | 24 | h4 { font-size: 1.2em; color: #1e36ce; }
| 25 | a { color: #1e36ce; text-decoration:none; } |  | 25 | a { color: #1e36ce; text-decoration:none; }
| 26 | tt { font-family: "Courier New", Courier; } |  | 26 | tt { font-family: "Courier New", Courier; }
| 27 | p { text-indent: 0px; } |  | 27 | p { text-indent: 0px; }
| 28 | hr { border: 0; width: 80%; border-bottom: 1px solid #aaa} |  | 28 | hr { border: 0; width: 80%; border-bottom: 1px solid #aaa}
| 29 | p.caption { width: 80%; font-style: normal; text-align: left; } |  | 29 | p.caption { width: 80%; font-style: normal; text-align: left; }
| 30 | hr.figure { border: 0; width: 80%; border-bottom: 1px solid #aaa; } |  | 30 | hr.figure { border: 0; width: 80%; border-bottom: 1px solid #aaa; }
| 31 | /* pre style removed because it will interfer with pygments */ |  | 31 | /* pre style removed because it will interfer with pygments */
| 32 | div.highlight { |  | 32 | div.highlight {
| 33 | border: 1px solid #cfcfcf; |  | 33 | border: 1px solid #cfcfcf;
| 34 | border-radius: 2px; |  | 34 | border-radius: 2px;
| 35 | line-height: 1.21429em; |  | 35 | line-height: 1.21429em;
| 36 | } |  | 36 | }
| 37 | div.cell { |  | 37 | div.cell {
| 38 | width: 100%; |  | 38 | width: 100%;
| 39 | padding: 5px 5px 5px 0; |  | 39 | padding: 5px 5px 5px 0;
| 40 | margin: 0; |  | 40 | margin: 0;
| 41 | outline: none; |  | 41 | outline: none;
| 42 | } |  | 42 | }
| 43 | div.input { |  | 43 | div.input {
| 44 | page-break-inside: avoid; |  | 44 | page-break-inside: avoid;
| 45 | box-orient: horizontal; |  | 45 | box-orient: horizontal;
| 46 | box-align: stretch; |  | 46 | box-align: stretch;
| 47 | display: flex; |  | 47 | display: flex;
| 48 | flex-direction: row; |  | 48 | flex-direction: row;
| 49 | align-items: stretch; |  | 49 | align-items: stretch;
| 50 | } |  | 50 | }
| 51 | div.inner_cell { |  | 51 | div.inner_cell {
| 52 | box-orient: vertical; |  | 52 | box-orient: vertical;
| 53 | box-align: stretch; |  | 53 | box-align: stretch;
| 54 | display: flex; |  | 54 | display: flex;
| 55 | flex-direction: column; |  | 55 | flex-direction: column;
| 56 | align-items: stretch; |  | 56 | align-items: stretch;
| 57 | box-flex: 1; |  | 57 | box-flex: 1;
| 58 | flex: 1; |  | 58 | flex: 1;
| 59 | } |  | 59 | }
| 60 | div.input_area { |  | 60 | div.input_area {
| 61 | border: 1px solid #cfcfcf; |  | 61 | border: 1px solid #cfcfcf;
| 62 | border-radius: 4px; |  | 62 | border-radius: 4px;
| 63 | background: #f7f7f7; |  | 63 | background: #f7f7f7;
| 64 | line-height: 1.21429em; |  | 64 | line-height: 1.21429em;
| 65 | } |  | 65 | }
| 66 | div.input_area > div.highlight { |  | 66 | div.input_area > div.highlight {
| 67 | margin: .4em; |  | 67 | margin: .4em;
| 68 | border: none; |  | 68 | border: none;
| 69 | padding: 0; |  | 69 | padding: 0;
| 70 | background-color: transparent; |  | 70 | background-color: transparent;
| 71 | } |  | 71 | }
| 72 | div.output_wrapper { |  | 72 | div.output_wrapper {
| 73 | position: relative; |  | 73 | position: relative;
| 74 | box-orient: vertical; |  | 74 | box-orient: vertical;
| 75 | box-align: stretch; |  | 75 | box-align: stretch;
| 76 | display: flex; |  | 76 | display: flex;
| 77 | flex-direction: column; |  | 77 | flex-direction: column;
| 78 | align-items: stretch; |  | 78 | align-items: stretch;
| 79 | } |  | 79 | }
| 80 | .output { |  | 80 | .output {
| 81 | box-orient: vertical; |  | 81 | box-orient: vertical;
| 82 | box-align: stretch; |  | 82 | box-align: stretch;
| 83 | display: flex; |  | 83 | display: flex;
| 84 | flex-direction: column; |  | 84 | flex-direction: column;
| 85 | align-items: stretch; |  | 85 | align-items: stretch;
| 86 | } |  | 86 | }
| 87 | div.output_area { |  | 87 | div.output_area {
| 88 | padding: 0; |  | 88 | padding: 0;
| 89 | page-break-inside: avoid; |  | 89 | page-break-inside: avoid;
| 90 | box-orient: horizontal; |  | 90 | box-orient: horizontal;
| 91 | box-align: stretch; |  | 91 | box-align: stretch;
| 92 | display: flex; |  | 92 | display: flex;
| 93 | flex-direction: row; |  | 93 | flex-direction: row;
| 94 | align-items: stretch; |  | 94 | align-items: stretch;
| 95 | } |  | 95 | }
| 96 | div.output_subarea { |  | 96 | div.output_subarea {
| 97 | padding: .4em .4em 0 .4em; |  | 97 | padding: .4em .4em 0 .4em;
| 98 | box-flex: 1; |  | 98 | box-flex: 1;
| 99 | flex: 1; |  | 99 | flex: 1;
| 100 | } |  | 100 | }
| 101 | div.output_text { |  | 101 | div.output_text {
| 102 | text-align: left; |  | 102 | text-align: left;
| 103 | color: #000; |  | 103 | color: #000;
| 104 | line-height: 1.21429em; |  | 104 | line-height: 1.21429em;
| 105 | } |  | 105 | }
| 106 | .alert-text-small { font-size: 80%; } |  | 106 | .alert-text-small { font-size: 80%; }
| 107 | .alert-text-large { font-size: 130%; } |  | 107 | .alert-text-large { font-size: 130%; }
| 108 | .alert-text-normal { font-size: 90%; } |  | 108 | .alert-text-normal { font-size: 90%; }
| 109 | .alert { |  | 109 | .alert {
| 110 | padding:8px 35px 8px 14px; margin-bottom:18px; |  | 110 | padding:8px 35px 8px 14px; margin-bottom:18px;
| 111 | text-shadow:0 1px 0 rgba(255,255,255,0.5); |  | 111 | text-shadow:0 1px 0 rgba(255,255,255,0.5);
| 112 | border:1px solid #bababa; |  | 112 | border:1px solid #bababa;
| 113 | border-radius: 4px; |  | 113 | border-radius: 4px;
| 114 | -webkit-border-radius: 4px; |  | 114 | -webkit-border-radius: 4px;
| 115 | -moz-border-radius: 4px; |  | 115 | -moz-border-radius: 4px;
| 116 | color: #555; |  | 116 | color: #555;
| 117 | background-color: #f8f8f8; |  | 117 | background-color: #f8f8f8;
| 118 | background-position: 10px 5px; |  | 118 | background-position: 10px 5px;
| 119 | background-repeat: no-repeat; |  | 119 | background-repeat: no-repeat;
| 120 | background-size: 38px; |  | 120 | background-size: 38px;
| 121 | padding-left: 55px; |  | 121 | padding-left: 55px;
| 122 | width: 75%; |  | 122 | width: 75%;
| 123 | } |  | 123 | }
| 124 | .alert-block {padding-top:14px; padding-bottom:14px} |  | 124 | .alert-block {padding-top:14px; padding-bottom:14px}
| 125 | .alert-block > p, .alert-block > ul {margin-bottom:1em} |  | 125 | .alert-block > p, .alert-block > ul {margin-bottom:1em}
| 126 | .alert li {margin-top: 1em} |  | 126 | .alert li {margin-top: 1em}
| 127 | .alert-block p+p {margin-top:5px} |  | 127 | .alert-block p+p {margin-top:5px}
| 128 | .alert-notice { background-image: url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_notice.png); } |  | 128 | .alert-notice { background-image: url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_notice.png); }
| 129 | .alert-summary { background-image:url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_summary.png); } |  | 129 | .alert-summary { background-image:url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_summary.png); }
| 130 | .alert-warning { background-image: url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_warning.png); } |  | 130 | .alert-warning { background-image: url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_warning.png); }
| 131 | .alert-question {background-image:url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_question.png); } |  | 131 | .alert-question {background-image:url(https://cdn.rawgit.com/doconce/doconce/master/bundled/html_images/small_gray_question.png); }
| 132 | div { text-align: justify; text-justify: inter-word; } |  | 132 | div { text-align: justify; text-justify: inter-word; }
| 133 | .tab { |  | 133 | .tab {
| 134 | padding-left: 1.5em; |  | 134 | padding-left: 1.5em;
| 135 | } |  | 135 | }
| 136 | div.toc p,a { |  | 136 | div.toc p,a {
| 137 | line-height: 1.3; |  | 137 | line-height: 1.3;
| 138 | margin-top: 1.1; |  | 138 | margin-top: 1.1;
| 139 | margin-bottom: 1.1; |  | 139 | margin-bottom: 1.1;
| 140 | } |  | 140 | }
| 141 | </style> |  | 141 | </style>
| 142 | </head> |  | 142 | </head>
| 143 |  |  | 143 |
| 144 | <!-- tocinfo |  | 144 | <!-- tocinfo
| 145 | {'highest level': 0, |  | 145 | {'highest level': 0,
| 146 | 'sections': [('Table of contents', |  | 146 | 'sections': [('Table of contents',
| 147 | 0, |  | 147 | 0,
| 148 | 'table_of_contents', |  | 148 | 'table_of_contents',
| 149 | 'table_of_contents'), |  | 149 | 'table_of_contents'),
| 150 | ('Commands to be commented out', |  | 150 | ('Commands to be commented out',
| 151 | 0, |  | 151 | 0,
| 152 | None, |  | 152 | None,
| 153 | 'commands-to-be-commented-out'), |  | 153 | 'commands-to-be-commented-out'),
| 154 | ('Chapters and Sections', 0, None, 'chapters-and-sections'), |  | 154 | ('Chapters and Sections', 0, None, 'chapters-and-sections'),
| 155 | ('Section 1', 1, 'sec1', 'sec1'), |  | 155 | ('Section 1', 1, 'sec1', 'sec1'),
| 156 | ('Subsection 1', 2, 'subsec1', 'subsec1'), |  | 156 | ('Subsection 1', 2, 'subsec1', 'subsec1'),
| 157 | ('subsection', 2, None, 'subsection'), |  | 157 | ('subsection', 2, None, 'subsection'),
| 158 | ('subsubsection', 3, None, 'subsubsection'), |  | 158 | ('subsubsection', 3, None, 'subsubsection'),
| 159 | ('Media', 2, None, 'media'), |  | 159 | ('Media', 2, None, 'media'),
| 160 | ('Inline Tags', 2, None, 'inline-tags'), |  | 160 | ('Inline Tags', 2, None, 'inline-tags'),
| 161 | ('Inline Tags 2', 2, None, 'inline-tags-2'), |  | 161 | ('Inline Tags 2', 2, None, 'inline-tags-2'),
| 162 | ('Subsubsection', 3, None, 'subsubsection'), |  | 162 | ('Subsubsection', 3, None, 'subsubsection'),
| 163 | ('Commands', 2, None, 'commands'), |  | 163 | ('Commands', 2, None, 'commands'),
| 164 | ('Code', 2, None, 'code'), |  | 164 | ('Code', 2, None, 'code'),
| 165 | ('Blocks', 1, None, 'blocks'), |  | 165 | ('Blocks', 1, None, 'blocks'),
| 166 | ('References', 2, None, 'references')]} |  | 166 | ('References', 2, None, 'references')]}
| 167 | end of tocinfo --> |  | 167 | end of tocinfo -->
| 168 |  |  | 168 |
| 169 | <body> |  | 169 | <body>
| 170 |  |  | 170 |
| 171 |  |  | 171 |
| 172 |  |  | 172 |
| 173 | <script type="text/x-mathjax-config"> |  | 173 | <script type="text/x-mathjax-config">
| 174 | MathJax.Hub.Config({ |  | 174 | MathJax.Hub.Config({
| 175 | TeX: { |  | 175 | TeX: {
| 176 | equationNumbers: { autoNumber: "AMS" }, |  | 176 | equationNumbers: { autoNumber: "AMS" },
| 177 | extensions: ["AMSmath.js", "AMSsymbols.js", "autobold.js", "color.js"] |  | 177 | extensions: ["AMSmath.js", "AMSsymbols.js", "autobold.js", "color.js"]
| 178 | } |  | 178 | }
| 179 | }); |  | 179 | });
| 180 | </script> |  | 180 | </script>
| 181 | <script type="text/javascript" async |  | 181 | <script type="text/javascript" async
| 182 | src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.1/MathJax.js?config=TeX-AMS-MML_HTMLorMML"> |  | 182 | src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.1/MathJax.js?config=TeX-AMS-MML_HTMLorMML">
| 183 | </script> |  | 183 | </script>
| 184 |  |  | 184 |
| 185 |  |  | 185 |
| 186 | <!-- ------------------- main content ---------------------- --> |  | 186 | <!-- ------------------- main content ---------------------- -->
| 187 | <center> |  | 187 | <center>
| 188 | <h1>Minimal slide demo</h1> |  | 188 | <h1>Minimal slide demo</h1>
| 189 | </center> <!-- document title --> |  | 189 | </center> <!-- document title -->
| 190 |  |  | 190 |
| 191 | <!-- author(s): Some Author, and Some Author2 --> |  | 191 | <!-- author(s): Some Author, and Some Author2 -->
| 192 | <center> |  | 192 | <center>
| 193 | <b>Some Author</b> [1] |  | 193 | <b>Some Author</b> [1]
| 194 | </center> |  | 194 | </center>
| 195 | <center> |  | 195 | <center>
| 196 | <b>Some Author2</b> [2, 3] (<tt>someemail at site.net</tt>) |  | 196 | <b>Some Author2</b> [2, 3] (<tt>someemail at site.net</tt>)
| 197 | </center> |  | 197 | </center>
| 198 | <!-- institution(s) --> |  | 198 | <!-- institution(s) -->
| 199 | <center> |  | 199 | <center>
| 200 | [1] <b>UiO</b> |  | 200 | [1] <b>UiO</b>
| 201 | </center> |  | 201 | </center>
| 202 | <center> |  | 202 | <center>
| 203 | [2] <b>institution1</b> |  | 203 | [2] <b>institution1</b>
| 204 | </center> |  | 204 | </center>
| 205 | <center> |  | 205 | <center>
| 206 | [3] <b>institution2</b> |  | 206 | [3] <b>institution2</b>
| 207 | </center> |  | 207 | </center>
| 208 | <br> |  | 208 | <br>
| 209 | <center> |  | 209 | <center>
| 210 | <h4>Apr 13, 2021</h4> |  | 210 | <h4>Apr 13, 2021</h4>
| 211 | </center> <!-- date --> |  | 211 | </center> <!-- date -->
| 212 | <br> |  | 212 | <br>
| 213 | <h1 id="table_of_contents">Table of contents</h1> |  | 213 | <h1 id="table_of_contents">Table of contents</h1>
| 214 |  |  | 214 |
| 215 | <div class='toc'> |  | 215 | <div class='toc'>
| 216 | <p><a href="#commands-to-be-commented-out"> Commands to be commented out </a></p> |  | 216 | <p><a href="#commands-to-be-commented-out"> Commands to be commented out </a></p>
| 217 | <p><a href="#chapters-and-sections"> Chapters and Sections </a></p> |  | 217 | <p><a href="#chapters-and-sections"> Chapters and Sections </a></p>
| 218 | <p><span class="tab"> <a href="#sec1"> Section 1 </a></p> |  | 218 | <p><span class="tab"> <a href="#sec1"> Section 1 </a></p>
| 219 | <p><span class="tab"> <span class="tab"> <a href="#subsec1"> Subsection 1 </a></p> |  | 219 | <p><span class="tab"> <span class="tab"> <a href="#subsec1"> Subsection 1 </a></p>
| 220 | <p><span class="tab"> <span class="tab"> <a href="#subsection"> subsection </a></p> |  | 220 | <p><span class="tab"> <span class="tab"> <a href="#subsection"> subsection </a></p>
| 221 | <p><span class="tab"> <span class="tab"> <a href="#media"> Media </a></p> |  | 221 | <p><span class="tab"> <span class="tab"> <a href="#media"> Media </a></p>
| 222 | <p><span class="tab"> <span class="tab"> <a href="#inline-tags"> Inline Tags </a></p> |  | 222 | <p><span class="tab"> <span class="tab"> <a href="#inline-tags"> Inline Tags </a></p>
| 223 | <p><span class="tab"> <span class="tab"> <a href="#inline-tags-2"> Inline Tags 2 </a></p> |  | 223 | <p><span class="tab"> <span class="tab"> <a href="#inline-tags-2"> Inline Tags 2 </a></p>
| 224 | <p><span class="tab"> <span class="tab"> <a href="#commands"> Commands </a></p> |  | 224 | <p><span class="tab"> <span class="tab"> <a href="#commands"> Commands </a></p>
| 225 | <p><span class="tab"> <span class="tab"> <a href="#code"> Code </a></p> |  | 225 | <p><span class="tab"> <span class="tab"> <a href="#code"> Code </a></p>
| 226 | <p><span class="tab"> <a href="#blocks"> Blocks </a></p> |  | 226 | <p><span class="tab"> <a href="#blocks"> Blocks </a></p>
| 227 | <p><span class="tab"> <span class="tab"> <a href="#references"> References </a></p> |  | 227 | <p><span class="tab"> <span class="tab"> <a href="#references"> References </a></p>
| 228 | </div> |  | 228 | </div>
| 229 | <br> |  | 229 | <br>
| 230 |  |  | 230 |
| 231 | <!-- !split --> |  | 231 | <!-- !split -->
n | 232 | <p>two inline tags in same line</p> | n | 232 | two inline tags in same line
| 233 | <a href="http://doconce.github.io/teamods/doconce/demo/demo_blue_shadow.pdf" target="_self"><tt>shadow</tt></a> |  | 233 | <a href="http://doconce.github.io/teamods/doconce/demo/demo_blue_shadow.pdf" target="_self"><tt>shadow</tt></a>
| 234 |  |  | 234 |
| 235 | <!-- !split --> |  | 235 | <!-- !split -->
| 236 | <center> |  | 236 | <center>
| 237 | <h1 id="commands-to-be-commented-out">Commands to be commented out </h1> |  | 237 | <h1 id="commands-to-be-commented-out">Commands to be commented out </h1>
| 238 | </center> <hr> |  | 238 | </center> <hr>
| 239 | <!-- !bslidecell 00 0.4 --> |  | 239 | <!-- !bslidecell 00 0.4 -->
| 240 | <ul> |  | 240 | <ul>
| 241 | <li> Scope</li> |  | 241 | <li> Scope</li>
| 242 | <li> Focus</li> |  | 242 | <li> Focus</li>
| 243 | <li> Approach</li> |  | 243 | <li> Approach</li>
| 244 | </ul> |  | 244 | </ul>
| 245 | <!-- !eslidecell --> |  | 245 | <!-- !eslidecell -->
| 246 | <!-- !bslidecell 01 0.6 --> |  | 246 | <!-- !bslidecell 01 0.6 -->
| 247 | <br /><br /><center> |  | 247 | <br /><br /><center>
| 248 | <p><img src="https://openclipart.org/people/jpneok/junebug.svg" align="bottom" width=200></p> |  | 248 | <p><img src="https://openclipart.org/people/jpneok/junebug.svg" align="bottom" width=200></p>
| 249 | </center> |  | 249 | </center>
| 250 | <br /><br/> |  | 250 | <br /><br/>
| 251 | <!-- !eslidecell --> |  | 251 | <!-- !eslidecell -->
| 252 |  |  | 252 |
| 253 | <div class="alert alert-block alert-block alert-text-normal"> |  | 253 | <div class="alert alert-block alert-block alert-text-normal">
| 254 | <b>Methods are slow or fast:</b> |  | 254 | <b>Methods are slow or fast:</b>
| 255 | <p> |  | 255 | <p>
| 256 | <!-- !bpop --> |  | 256 | <!-- !bpop -->
| 257 | <ul> |  | 257 | <ul>
| 258 | <li> Slow:</li> |  | 258 | <li> Slow:</li>
| 259 | <ul> |  | 259 | <ul>
| 260 | <li> Pick-and-choose</li> |  | 260 | <li> Pick-and-choose</li>
| 261 | </ul> |  | 261 | </ul>
| 262 | <li> Fast:</li> |  | 262 | <li> Fast:</li>
| 263 | <ul> |  | 263 | <ul>
| 264 | <li> Quickstep</li> |  | 264 | <li> Quickstep</li>
| 265 | <li> MMST</li> |  | 265 | <li> MMST</li>
| 266 | </ul> |  | 266 | </ul>
| 267 | </ul> |  | 267 | </ul>
| 268 | <!-- !epop --> |  | 268 | <!-- !epop -->
| 269 | </div> |  | 269 | </div>
| 270 |  |  | 270 |
| 271 |  |  | 271 |
| 272 | <!-- !split --> |  | 272 | <!-- !split -->
| 273 | <center> |  | 273 | <center>
| 274 | <h1 id="chapters-and-sections">Chapters and Sections </h1> |  | 274 | <h1 id="chapters-and-sections">Chapters and Sections </h1>
| 275 | </center> <hr> |  | 275 | </center> <hr>
n | 276 | <p>TODO?: title and TOC headers collide TODO? Chapter has an issue here related to css in deck slides. It is this html code <code>&lt;center&gt;&lt;/p&gt; | n | 276 | TODO?: title and TOC headers collide
|  |  |  | 277 | TODO? Chapter has an issue here related to css in deck slides. It is this html code
|  |  |  | 278 | <code>&lt;center&gt;
| 277 | &lt;h1 id=&quot;chapter&quot;&gt;chapter &lt;/h1&gt; |  | 279 | &lt;h1 id=&quot;chapter&quot;&gt;chapter &lt;/h1&gt;
n | 278 | &lt;p&gt;&lt;/center&gt; &lt;hr&gt; </code></p> | n | 280 | &lt;/center&gt; &lt;hr&gt;
|  |  |  | 281 | </code>
| 279 | <h1 id="sec1">Section 1</h1> |  | 282 | <h1 id="sec1">Section 1</h1>
| 280 | <h2 id="subsec1">Subsection 1</h2> |  | 283 | <h2 id="subsec1">Subsection 1</h2>
| 281 |  |  | 284 |
n |  |  | n | 285 | <p>__Abstract.__ on two
|  |  |  | 286 | <h2 id="subsec1">Subsection 1</h2>
| 282 | <p> |  | 287 | </p>
| 283 | <b>Abstract.</b> on two lines</p> |  | 288 | lines
| 284 | <h2 id="subsection">subsection </h2> |  | 289 | <h2 id="subsection">subsection </h2>
| 285 | <h3 id="subsubsection">subsubsection </h3> |  | 290 | <h3 id="subsubsection">subsubsection </h3>
n | 286 | <p>Horizontal rule:</p> | n | 291 | Horizontal rule:
| 287 | <hr> |  | 292 | <hr>
| 288 |  |  | 293 |
| 289 | <!-- !split --> |  | 294 | <!-- !split -->
| 290 | <h2 id="media">Media </h2> |  | 295 | <h2 id="media">Media </h2>
| 291 |  |  | 296 |
| 292 | <center> <!-- figure label: --> <div id="myfig"></div> <!-- FIGURE --> |  | 297 | <center> <!-- figure label: --> <div id="myfig"></div> <!-- FIGURE -->
| 293 | <hr class="figure"> |  | 298 | <hr class="figure">
| 294 | <center> |  | 299 | <center>
| 295 | <p class="caption">Figure 1: Results for \( a=2 \). <!-- caption label: myfig --> </p> |  | 300 | <p class="caption">Figure 1: Results for \( a=2 \). <!-- caption label: myfig --> </p>
| 296 | </center> |  | 301 | </center>
| 297 | <p><img src="https://openclipart.org/people/jpneok/junebug.svg" align="bottom" width=200></p> |  | 302 | <p><img src="https://openclipart.org/people/jpneok/junebug.svg" align="bottom" width=200></p>
| 298 | </center> |  | 303 | </center>
| 299 |  |  | 304 |
| 300 | <iframe width="420" height="315" src="https://www.youtube.com/embed/P8VcZzgdfSc" frameborder="0" allowfullscreen></iframe> |  | 305 | <iframe width="420" height="315" src="https://www.youtube.com/embed/P8VcZzgdfSc" frameborder="0" allowfullscreen></iframe>
| 301 |  |  | 306 |
| 302 | <!-- !split --> |  | 307 | <!-- !split -->
| 303 | <h2 id="inline-tags">Inline Tags </h2> |  | 308 | <h2 id="inline-tags">Inline Tags </h2>
n | 304 | <p>normal text on top</p> | n | 309 | normal text on top
| 305 |  |  | 310 |
n | 306 | <p>This text has one, two, three lines</p> | n | 311 | This text has one,
|  |  |  | 312 | two,
|  |  |  | 313 | three lines
| 307 |  |  | 314 |
n | 308 | <p>Inline Mathematics: \( a^2=\sin(x) \).</p> | n | 315 | Inline Mathematics: \( a^2=\sin(x) \).
| 309 | <p> |  |  |
| 310 | <b>Paragraph with running..</b> |  | 316 | <p>__Paragraph with running..__ tex
| 311 | text</p> |  | 317 | \( a^2=\sin(x) \).
| 312 | <p> |  | 318 | th running..__ text</p>
| 313 | <b>Only Paragraph.</b> |  | 319 | <p><b>_Only Paragraph.</b>
|  |  |  | 320 | \( a^2=\sin(x) \).
|  |  |  | 321 | ph.__</p>
| 314 | Some <em>Italics</em> with text</p> |  | 322 | Some <em>Italics</em> with text
| 315 | <em>Only Italics</em> |  | 323 | <em>Only Italics</em>
n | 316 | <p>Some <b>Bold</b> with text</p> | n | 324 | Some <b>Bold</b> with text
| 317 | <b>Only Bold</b> |  | 325 | <b>Only Bold</b>
| 318 |  |  | 326 |
n | 319 | <p> | n |  |
| 320 | <b>No newline after this.</b> |  | 327 | <p><b>_No newline after this.</b>
|  |  |  | 328 | <b>Only Bold</b>
|  |  |  | 329 | ne after this.__</p>
| 321 | The text continues on two more lines. </p> |  | 330 | The text continues on two more
|  |  |  | 331 | lines.
| 322 |  |  | 332 |
n | 323 | <p>more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text </p> | n | 333 | more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text
| 324 |  |  | 334 |
n | 325 | <p>blank line, even more text</p> | n | 335 | blank line, even more text
| 326 |  |  | 336 |
| 327 | <!-- !split --> |  | 337 | <!-- !split -->
| 328 | <h2 id="inline-tags-2">Inline Tags 2 </h2> |  | 338 | <h2 id="inline-tags-2">Inline Tags 2 </h2>
n | 329 | <p>inline comment here | n | 339 | inline comment here
| 330 | <!-- begin inline comment --> |  | 340 | <!-- begin inline comment -->
| 331 | <font color="red">(<b>Alessandro 1</b>: has a comment)</font> |  | 341 | <font color="red">(<b>Alessandro 1</b>: has a comment)</font>
| 332 | <!-- end inline comment --> |  | 342 | <!-- end inline comment -->
n | 333 | </p> | n |  |
| 334 | <h3 id="subsubsection">Subsubsection </h3> |  | 343 | <h3 id="subsubsection">Subsubsection </h3>
n | 335 | <p>text with a line-<br /> break normal text non-breaking space using tilde: 7.4&nbsp;km Guns &amp; Roses Texas A&amp;M emoji: <img src="https://raw.githubusercontent.com/hplgit/doconce/master/bundled/emoji/png/smile.png" width="22px" height="22px" align="center"> </p> | n | 344 | text with a line-<br />
|  |  |  | 345 | break
|  |  |  | 346 | normal text
|  |  |  | 347 | non-breaking space using tilde: 7.4&nbsp;km
|  |  |  | 348 | Guns &amp; Roses
|  |  |  | 349 | Texas A&amp;M
|  |  |  | 350 | emoji: <img src="https://raw.githubusercontent.com/hplgit/doconce/master/bundled/emoji/png/smile.png" width="22px" height="22px" align="center">
| 336 |  |  | 351 |
n | 337 | <p>test footnotes [<a id="link_footnote_1" href="#def_footnote_1">1</a>]</p> | n | 352 | test footnotes [<a id="link_footnote_1" href="#def_footnote_1">1</a>]
| 338 |  |  | 353 |
| 339 | <p id="def_footnote_1"><a href="#link_footnote_1"><b>1:</b></a> Typesetting of the footnote depends on the format.</p> |  | 354 | <p id="def_footnote_1"><a href="#link_footnote_1"><b>1:</b></a> Typesetting of the footnote depends on the format.</p>
| 340 |  |  | 355 |
| 341 | <!-- !split --> |  | 356 | <!-- !split -->
| 342 | <h2 id="commands">Commands </h2> |  | 357 | <h2 id="commands">Commands </h2>
n | 343 | <p>a ref: <a href="#myfig">1</a></p> | n | 358 | a ref: <a href="#myfig">1</a>
| 344 |  |  | 359 |
n | 345 | <p>Here is a citation using cite: <a href="#Langtangen_Pedersen_2002">[1]</a> Four citations: <a href="#Langtangen_1992c">[2]</a> <a href="#Langtangen_1994a">[3]</a> <a href="#Mortensen_et_al_2011">[4]</a> <a href="#Langtangen_Pedersen_2002">[1]</a></p> | n | 360 | Here is a citation using cite: <a href="#Langtangen_Pedersen_2002">[1]</a>
|  |  |  | 361 | Four citations: <a href="#Langtangen_1992c">[2]</a> <a href="#Langtangen_1994a">[3]</a> <a href="#Mortensen_et_al_2011">[4]</a> <a href="#Langtangen_Pedersen_2002">[1]</a>
| 346 |  |  | 362 |
| 347 | <b>nested list:TODO</b> |  | 363 | <b>nested list:TODO</b>
| 348 |  |  | 364 |
| 349 | <ul> |  | 365 | <ul>
| 350 | <li> item1</li> |  | 366 | <li> item1</li>
| 351 | <li> item2</li> |  | 367 | <li> item2</li>
| 352 | <li> item3 which continues on the next line to test that feature</li> |  | 368 | <li> item3 which continues on the next line to test that feature</li>
| 353 | <li> and a sublist</li> |  | 369 | <li> and a sublist</li>
| 354 | <ul> |  | 370 | <ul>
| 355 | <li> with indented subitem1</li> |  | 371 | <li> with indented subitem1</li>
| 356 | <li> and a subitem2</li> |  | 372 | <li> and a subitem2</li>
| 357 | </ul> |  | 373 | </ul>
| 358 | <li> and perhaps an ordered sublist |  | 374 | <li> and perhaps an ordered sublist
| 359 | <ol type="a"></li> |  | 375 | <ol type="a"></li>
| 360 | <li> first item</li> |  | 376 | <li> first item</li>
| 361 | <li> second item, continuing on a new line</li> |  | 377 | <li> second item, continuing on a new line</li>
| 362 | </ol> |  | 378 | </ol>
| 363 | <dt>keyword1:<dd> |  | 379 | <dt>keyword1:<dd>
n | 364 | <p> TODO explanation of keyword1</p> | n | 380 | TODO explanation of keyword1
| 365 | <dt>keyword2:<dd> |  | 381 | <dt>keyword2:<dd>
n | 366 | <p> explanation of keyword2</p> | n | 382 | explanation of keyword2
| 367 | </ul> |  | 383 | </ul>
| 368 | <b>tables</b> |  | 384 | <b>tables</b>
| 369 |  |  | 385 |
| 370 | <table class="table" border="1"> |  | 386 | <table class="table" border="1">
| 371 | <thead> |  | 387 | <thead>
| 372 | <tr><th align="center">time</th> <th align="center">velocity</th> <th align="center">acceleration</th> </tr> |  | 388 | <tr><th align="center">time</th> <th align="center">velocity</th> <th align="center">acceleration</th> </tr>
| 373 | </thead> |  | 389 | </thead>
| 374 | <tbody> |  | 390 | <tbody>
| 375 | <tr><td align="left"> 0.0 </td> <td align="right"> 1.4186 </td> <td align="right"> -5.01 </td> </tr> |  | 391 | <tr><td align="left"> 0.0 </td> <td align="right"> 1.4186 </td> <td align="right"> -5.01 </td> </tr>
| 376 | <tr><td align="left"> 2.0 </td> <td align="right"> 1.376512 </td> <td align="right"> 11.919 </td> </tr> |  | 392 | <tr><td align="left"> 2.0 </td> <td align="right"> 1.376512 </td> <td align="right"> 11.919 </td> </tr>
| 377 | </tbody> |  | 393 | </tbody>
| 378 | </table> |  | 394 | </table>
| 379 |  |  | 395 |
| 380 | <!-- !split --> |  | 396 | <!-- !split -->
| 381 | <h2 id="code">Code </h2> |  | 397 | <h2 id="code">Code </h2>
n | 382 | <p>Verbatim above <code>pycod -t</code></p> | n | 398 | Verbatim above <code>pycod -t</code>
| 383 |  |  | 399 |
| 384 | <!-- code=python (!bc pycod) typeset with pygments style "default" --> |  | 400 | <!-- code=python (!bc pycod) typeset with pygments style "default" -->
| 385 | <div class="cell border-box-sizing code_cell rendered"> |  | 401 | <div class="cell border-box-sizing code_cell rendered">
| 386 | <div class="input"> |  | 402 | <div class="input">
| 387 | <div class="inner_cell"> |  | 403 | <div class="inner_cell">
| 388 | <div class="input_area"> |  | 404 | <div class="input_area">
| 389 | <div class="highlight" style="background: #f8f8f8"> |  | 405 | <div class="highlight" style="background: #f8f8f8">
| 390 | <pre style="line-height: 125%;">total <span style="color: #666666">=</span> <span style="color: #666666">0</span> |  | 406 | <pre style="line-height: 125%;">total <span style="color: #666666">=</span> <span style="color: #666666">0</span>
| 391 | </pre> |  | 407 | </pre>
| 392 | </div> |  | 408 | </div>
| 393 | </div> |  | 409 | </div>
| 394 | </div> |  | 410 | </div>
| 395 | </div> |  | 411 | </div>
| 396 | <div class="output_wrapper"> |  | 412 | <div class="output_wrapper">
| 397 | <div class="output"> |  | 413 | <div class="output">
| 398 | <div class="output_area"> |  | 414 | <div class="output_area">
| 399 | <div class="output_subarea output_stream output_stdout output_text"> |  | 415 | <div class="output_subarea output_stream output_stdout output_text">
| 400 | </div> |  | 416 | </div>
| 401 | </div> |  | 417 | </div>
| 402 | </div> |  | 418 | </div>
| 403 | </div> |  | 419 | </div>
| 404 | </div> |  | 420 | </div>
| 405 |  |  | 421 |
n | 406 | <p>Verbatim below <code>pycod -t</code></p> | n | 422 | Verbatim below <code>pycod -t</code>
| 407 |  |  | 423 |
| 408 | <!-- !split --> |  | 424 | <!-- !split -->
| 409 | <h1 id="blocks">Blocks </h1> |  | 425 | <h1 id="blocks">Blocks </h1>
| 410 |  |  | 426 |
n | 411 | <p> | n |  |
| 412 | <b>!bquote</b> |  | 427 | <p><b>_!bquote</b>
|  |  |  | 428 | <h1 id="blocks">Blocks </h1>
|  |  |  | 429 | </p>
| 413 | A quote:</p> |  | 430 | A quote:
| 414 |  |  | 431 |
| 415 | <blockquote> |  | 432 | <blockquote>
n | 416 | <p>Sayre's law states that &quot;in any dispute the intensity of feeling is inversely proportional to the value of the issues at stake.&quot; <br /> By way of corollary, it adds: <br /> &quot;That is why academic politics are so bitter.&quot; <br /> <em>Source</em>: <a href="https://en.wikipedia.org/wiki/Sayre's_law" target="_self">wikipedia</a></p> | n | 433 | Sayre's law states that
|  |  |  | 434 | &quot;in any dispute the intensity of feeling is inversely
|  |  |  | 435 | proportional to the value of the issues at stake.&quot; <br />
|  |  |  | 436 | By way of corollary, it adds: <br />
|  |  |  | 437 | &quot;That is why academic politics are so bitter.&quot; <br />
|  |  |  | 438 | <em>Source</em>: <a href="https://en.wikipedia.org/wiki/Sayre's_law" target="_self">wikipedia</a>
| 417 | </blockquote> |  | 439 | </blockquote>
| 418 |  |  | 440 |
| 419 |  |  | 441 |
n | 420 | <p> | n |  |
| 421 | <b>!bbox and !bt.</b> |  | 442 | <p><b>_!bbox and !bt.</b>
| 422 | </p> |  | 443 | <em>Source</em>:
|  |  |  | 444 | and !bt.__</p>
| 423 |  |  | 445 |
| 424 | <!-- begin box --> |  | 446 | <!-- begin box -->
| 425 | <div style="width: 95%; padding: 10px; border: 1px solid #000; border-radius: 4px;"> |  | 447 | <div style="width: 95%; padding: 10px; border: 1px solid #000; border-radius: 4px;">
n | 426 | <p>A generic equation</p> | n | 448 | A generic equation
| 427 |  |  | 449 |
| 428 | $$ f(x) = 0 $$ |  | 450 | $$ f(x) = 0 $$
| 429 |  |  | 451 |
n | 430 | <p>must be solved by a numerical method, such as</p> | n | 452 | must be solved by a numerical method, such as
| 431 |  |  | 453 |
| 432 | <ul> |  | 454 | <ul>
| 433 | <li> Newton's method</li> |  | 455 | <li> Newton's method</li>
| 434 | <li> The Bisection method</li> |  | 456 | <li> The Bisection method</li>
| 435 | <li> Fixed-point (Picard) iteration by rewriting \( f(x)=x - g(x) \)</li> |  | 457 | <li> Fixed-point (Picard) iteration by rewriting \( f(x)=x - g(x) \)</li>
| 436 | <li> The Secant method</li> |  | 458 | <li> The Secant method</li>
| 437 | </ul> |  | 459 | </ul>
| 438 | </div> |  | 460 | </div>
| 439 | <!-- end box --> |  | 461 | <!-- end box -->
| 440 |  |  | 462 |
| 441 |  |  | 463 |
n | 442 | <p> | n |  |
| 443 | <b>!bwarning.</b> |  | 464 | <p><b>_!bwarning.</b>
| 444 | </p> |  | 465 | <em>Source</em>:
|  |  |  | 466 | ing.__</p>
| 445 | <div class="alert alert-block alert-warning alert-text-large"> |  | 467 | <div class="alert alert-block alert-warning alert-text-large">
| 446 | <b>Watch out for \( \nabla\cdot\boldsymbol{u}=0 \) equations</b> |  | 468 | <b>Watch out for \( \nabla\cdot\boldsymbol{u}=0 \) equations</b>
| 447 | <p> |  | 469 | <p>
t | 448 | <p>Divergence freedom is often problematic from a numerical point of view.</p> | t | 470 | Divergence freedom is often problematic from a numerical point
|  |  |  | 471 | of view.
| 449 | </div> |  | 472 | </div>
| 450 |  |  | 473 |
| 451 | <h2 id="references">References </h2> |  | 474 | <h2 id="references">References </h2>
| 452 |  |  | 475 |
| 453 | <!-- begin bibliography --> |  | 476 | <!-- begin bibliography -->
| 454 | <ol> |  | 477 | <ol>
| 455 | <li> <div id="Langtangen_Pedersen_2002"></div> <b>H. P. Langtangen and G. Pedersen</b>. Propagation of Large Destructive Waves, <em>International Journal of Applied Mechanics and Engineering</em>, 7(1), pp. 187-204, 2002.</li> |  | 478 | <li> <div id="Langtangen_Pedersen_2002"></div> <b>H. P. Langtangen and G. Pedersen</b>. Propagation of Large Destructive Waves, <em>International Journal of Applied Mechanics and Engineering</em>, 7(1), pp. 187-204, 2002.</li>
| 456 | <li> <div id="Langtangen_1992c"></div> <b>H. P. Langtangen</b>. Stochastic Breakthrough Time Analysis of an Enhanced Oil Recovery Process, <em>SIAM Journal on Scientific Computing</em>, 13, pp. 1394-1417, 1992.</li> |  | 479 | <li> <div id="Langtangen_1992c"></div> <b>H. P. Langtangen</b>. Stochastic Breakthrough Time Analysis of an Enhanced Oil Recovery Process, <em>SIAM Journal on Scientific Computing</em>, 13, pp. 1394-1417, 1992.</li>
| 457 | <li> <div id="Langtangen_1994a"></div> <b>H. P. Langtangen</b>. Numerical Solution of First Passage Problems in Random Vibrations, <em>SIAM Journal of Scientific and Statistical Computing</em>, 15, pp. 997-996, 1994.</li> |  | 480 | <li> <div id="Langtangen_1994a"></div> <b>H. P. Langtangen</b>. Numerical Solution of First Passage Problems in Random Vibrations, <em>SIAM Journal of Scientific and Statistical Computing</em>, 15, pp. 997-996, 1994.</li>
| 458 | <li> <div id="Mortensen_et_al_2011"></div> <b>M. Mortensen, H. P. Langtangen and G. N. Wells</b>. A FEniCS-Based Programming Framework for Modeling Turbulent Flow by the Reynolds-Averaged Navier-Stokes Equations, <em>Advances in Water Resources</em>, 34(9), <a href="https://dx.doi.org/10.1016/j.advwatres.2011.02.013" target="_self">doi: 10.1016/j.advwatres.2011.02.013</a>, 2011.</li> |  | 481 | <li> <div id="Mortensen_et_al_2011"></div> <b>M. Mortensen, H. P. Langtangen and G. N. Wells</b>. A FEniCS-Based Programming Framework for Modeling Turbulent Flow by the Reynolds-Averaged Navier-Stokes Equations, <em>Advances in Water Resources</em>, 34(9), <a href="https://dx.doi.org/10.1016/j.advwatres.2011.02.013" target="_self">doi: 10.1016/j.advwatres.2011.02.013</a>, 2011.</li>
| 459 | </ol> |  | 482 | </ol>
| 460 | <!-- end bibliography --> |  | 483 | <!-- end bibliography -->
| 461 |  |  | 484 |
| 462 | <!-- ------------------- end of main content --------------- --> |  | 485 | <!-- ------------------- end of main content --------------- -->
| 463 | </body> |  | 486 | </body>
| 464 | </html> |  | 487 | </html>
| 465 |  |  | 488 |
| 466 |  |  | 489 |